@@ -1,5 +1,5 @@
-spread.labels<-function (x,y,labels=NULL,offset,bg="white",border=FALSE,
- between=FALSE,linecol=par("fg"),...) {
+spread.labels<-function (x,y,labels=NULL,ony=NA,offsets=NA,between=FALSE,
+ linecol=par("fg"),srt=0,...) {
 
  if(missing(x)) 
   stop("Usage: spread.labels(x,y,labels,...)")
@@ -16,18 +16,24 @@ spread.labels<-function (x,y,labels=NULL,offset,bg="white",border=FALSE,
   # now the right lines
   segments(x[(nlabels+1):ny],y[(nlabels+1):ny],labelx+strwidth(labels)/2,newy,
    col=linecol[2])
-  boxed.labels(labelx,newy,labels,bg=bg,border=border,...)
+  text(labelx,newy,labels,srt=srt,...)
  }
  else {
-  if(diff(range(x))<diff(range(y))) {
+  if(is.na(ony)) {
+   xylim<-par("usr")
+   ony<-diff(range(x))/(xylim[2]-xylim[1])<diff(range(y))(xylim[4]-xylim[3])
+  }
+  if(ony) {
    sort.index<-sort.list(y)
    x<-x[sort.index]
    y<-y[sort.index]
    newy<-seq(y[1],y[ny],length=length(labels))
-   if(missing(offset)) offset<-diff(par("usr")[1:2])/4
-   offsets<-rep(c(offset, -offset), ny/2 + 1)[1:ny]
+   if(is.na(offsets)) {
+    offset<-diff(par("usr")[1:2])/4
+    offsets<-rep(c(offset, -offset), ny/2 + 1)[1:ny]
+   }
    segments(x+offsets,newy,x,y)
-   boxed.labels(x+offsets,newy,labels[sort.index],bg=bg,border=border,...)
+   text(x+offsets,newy,labels[sort.index],srt=srt,pos=c(4,2),...)
   }
   else {
    sort.index<-sort.list(x)
@@ -35,10 +41,12 @@ spread.labels<-function (x,y,labels=NULL,offset,bg="white",border=FALSE,
    y<-y[sort.index]
    nx<-length(x)
    newx <- seq(x[1],x[nx],length=length(labels))
-   if(missing(offset)) offset<-diff(par("usr")[3:4])/4
-   offsets<-rep(c(offset,-offset),nx/2+1)[1:nx]
+   if(missing(offsets)) {
+    offset<-diff(par("usr")[3:4])/4
+    offsets<-rep(c(offset,-offset),nx/2+1)[1:nx]
+   }
    segments(newx,y+offsets,x,y)
-   boxed.labels(newx,y+offsets,labels[sort.index],bg=bg,border=border,...)
+   text(newx,y+offsets,labels[sort.index],srt=srt,...)
   }
  }
-}
\ No newline at end of file
+}
